@@ -21,6 +21,10 @@ describe 'heat::cache' do
           :memcache_servers                     => '<SERVICE DEFAULT>',
           :memcache_dead_retry                  => '<SERVICE DEFAULT>',
           :memcache_socket_timeout              => '<SERVICE DEFAULT>',
+          :enable_socket_keepalive              => '<SERVICE DEFAULT>',
+          :socket_keepalive_idle                => '<SERVICE DEFAULT>',
+          :socket_keepalive_interval            => '<SERVICE DEFAULT>',
+          :socket_keepalive_count               => '<SERVICE DEFAULT>',
           :memcache_pool_maxsize                => '<SERVICE DEFAULT>',
           :memcache_pool_unused_timeout         => '<SERVICE DEFAULT>',
           :memcache_pool_connection_get_timeout => '<SERVICE DEFAULT>',
@@ -29,6 +33,12 @@ describe 'heat::cache' do
           :tls_certfile                         => '<SERVICE DEFAULT>',
           :tls_keyfile                          => '<SERVICE DEFAULT>',
           :tls_allowed_ciphers                  => '<SERVICE DEFAULT>',
+          :enable_retry_client                  => '<SERVICE DEFAULT>',
+          :retry_attempts                       => '<SERVICE DEFAULT>',
+          :retry_delay                          => '<SERVICE DEFAULT>',
+          :hashclient_retry_attempts            => '<SERVICE DEFAULT>',
+          :hashclient_retry_delay               => '<SERVICE DEFAULT>',
+          :dead_timeout                         => '<SERVICE DEFAULT>',
           :manage_backend_package               => true,
         )
         is_expected.to contain_heat_config('constraint_validation_cache/caching').with_value('<SERVICE DEFAULT>')
@@ -52,10 +62,20 @@ describe 'heat::cache' do
           :memcache_servers                      => ['memcached01:11211', 'memcached02:11211'],
           :memcache_dead_retry                   => '60',
           :memcache_socket_timeout               => '300.0',
+          :enable_socket_keepalive               => false,
+          :socket_keepalive_idle                 => 1,
+          :socket_keepalive_interval             => 1,
+          :socket_keepalive_count                => 1,
           :memcache_pool_maxsize                 => '10',
           :memcache_pool_unused_timeout          => '120',
           :memcache_pool_connection_get_timeout  => '360',
           :tls_enabled                           => false,
+          :enable_retry_client                   => false,
+          :retry_attempts                        => 2,
+          :retry_delay                           => 0,
+          :hashclient_retry_attempts             => 2,
+          :hashclient_retry_delay                => 1,
+          :dead_timeout                          => 60,
           :manage_backend_package                => false,
           :constraint_validation_caching         => true,
           :constraint_validation_expiration_time => '3600',
@@ -78,6 +98,10 @@ describe 'heat::cache' do
           :memcache_servers                     => ['memcached01:11211', 'memcached02:11211'],
           :memcache_dead_retry                  => '60',
           :memcache_socket_timeout              => '300.0',
+          :enable_socket_keepalive              => false,
+          :socket_keepalive_idle                => 1,
+          :socket_keepalive_interval            => 1,
+          :socket_keepalive_count               => 1,
           :memcache_pool_maxsize                => '10',
           :memcache_pool_unused_timeout         => '120',
           :memcache_pool_connection_get_timeout => '360',
@@ -86,6 +110,12 @@ describe 'heat::cache' do
           :tls_certfile                         => '<SERVICE DEFAULT>',
           :tls_keyfile                          => '<SERVICE DEFAULT>',
           :tls_allowed_ciphers                  => '<SERVICE DEFAULT>',
+          :enable_retry_client                  => false,
+          :retry_attempts                       => 2,
+          :retry_delay                          => 0,
+          :hashclient_retry_attempts            => 2,
+          :hashclient_retry_delay               => 1,
+          :dead_timeout                         => 60,
           :manage_backend_package               => false,
         )
         is_expected.to contain_heat_config('constraint_validation_cache/caching').with_value('true')
