@@ -41,7 +41,7 @@ describe 'heat' do
     it_configures 'with SSL enabled without kombu'
     it_configures 'with SSL disabled'
     it_configures 'with enable_stack_adopt and enable_stack_abandon set'
-    it_configures 'with overridden transport_url parameter'
+    it_configures 'with overridden messaging default parameters'
     it_configures 'with notification_driver set to a string'
 
     context 'with amqp messaging' do
@@ -75,10 +75,13 @@ describe 'heat' do
       is_expected.to contain_heat_config('DEFAULT/host').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'configures default transport_url' do
-      is_expected.to contain_heat_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_heat_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
+    it 'configures default messaging default parameters' do
+      is_expected.to contain_oslo__messaging__default('heat_config').with(
+        :transport_url             => '<SERVICE DEFAULT>',
+        :rpc_response_timeout      => '<SERVICE DEFAULT>',
+        :control_exchange          => '<SERVICE DEFAULT>',
+        :executor_thread_pool_size => '<SERVICE DEFAULT>',
+      )
     end
 
     it 'configures max_template_size' do
@@ -89,30 +92,6 @@ describe 'heat' do
       is_expected.to contain_heat_config('DEFAULT/max_json_body_size').with_value('<SERVICE DEFAULT>')
     end
 
-    it 'configures user_domain_*' do
-      is_expected.to contain_heat_config('trustee/user_domain_name').with_value( 'Default' )
-    end
-
-    it 'configures auth_type' do
-      is_expected.to contain_heat_config('trustee/auth_type').with_value( 'password' )
-    end
-
-    it 'configures auth_url' do
-      is_expected.to contain_heat_config('trustee/auth_url').with_value( 'http://127.0.0.1:5000/' )
-    end
-
-    it 'configures username' do
-      is_expected.to contain_heat_config('trustee/username').with_value( 'heat' )
-    end
-
-    it 'configures ' do
-      is_expected.to contain_heat_config('trustee/password').with_secret( true )
-    end
-
-    it 'configures endpoint_type for clients' do
-      is_expected.to contain_heat_config('clients/endpoint_type').with_value( '<SERVICE DEFAULT>' )
-    end
-
     it 'configures keystone_ec2_uri' do
       is_expected.to contain_heat_config('ec2authtoken/auth_uri').with_value( '<SERVICE DEFAULT>' )
     end
@@ -141,29 +120,28 @@ describe 'heat' do
         :max_request_body_size        => '<SERVICE DEFAULT>',
       )
     end
-
-    it 'sets clients_heat url' do
-      is_expected.to contain_heat_config('clients_heat/url').with_value('<SERVICE DEFAULT>')
-    end
-
   end
 
   shared_examples_for 'configures default rabbitmq parameters' do
     it 'configures rabbit' do
       is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
-        :kombu_ssl_version           => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-        :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-        :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-        :kombu_compression           => '<SERVICE DEFAULT>',
-        :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-        :heartbeat_rate              => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-        :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-        :amqp_durable_queues         => '<SERVICE DEFAULT>',
-        :rabbit_ha_queues            => '<SERVICE DEFAULT>',
+        :kombu_ssl_version               => '<SERVICE DEFAULT>',
+        :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+        :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+        :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+        :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
+        :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+        :kombu_compression               => '<SERVICE DEFAULT>',
+        :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+        :heartbeat_rate                  => '<SERVICE DEFAULT>',
+        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+        :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+        :amqp_durable_queues             => '<SERVICE DEFAULT>',
+        :rabbit_ha_queues                => '<SERVICE DEFAULT>',
+        :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+        :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+        :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+        :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
       )
     end
   end
@@ -176,19 +154,23 @@ describe 'heat' do
 
     it 'configures rabbit' do
       is_expected.to contain_oslo__messaging__rabbit('heat_config').with(
-        :kombu_ssl_version           => '<SERVICE DEFAULT>',
-        :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
-        :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
-        :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
-        :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
-        :kombu_failover_strategy     => '<SERVICE DEFAULT>',
-        :kombu_compression           => '<SERVICE DEFAULT>',
-        :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
-        :heartbeat_rate              => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
-        :rabbit_use_ssl              => '<SERVICE DEFAULT>',
-        :amqp_durable_queues         => true,
-        :rabbit_ha_queues            => true,
+        :kombu_ssl_version               => '<SERVICE DEFAULT>',
+        :kombu_ssl_keyfile               => '<SERVICE DEFAULT>',
+        :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
+        :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
+        :kombu_reconnect_delay           => '<SERVICE DEFAULT>',
+        :kombu_failover_strategy         => '<SERVICE DEFAULT>',
+        :kombu_compression               => '<SERVICE DEFAULT>',
+        :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
+        :heartbeat_rate                  => '<SERVICE DEFAULT>',
+        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+        :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
+        :amqp_durable_queues             => true,
+        :rabbit_ha_queues                => true,
+        :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
+        :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
+        :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
+        :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
       )
     end
   end
@@ -257,18 +239,6 @@ describe 'heat' do
     )}
   end
 
-  shared_examples_for 'with heat_clients_endpoint_type set' do
-    before do
-      params.merge!(
-        :heat_clients_endpoint_type => 'internal',
-      )
-    end
-
-    it do
-      is_expected.to contain_heat_config('clients/endpoint_type').with_value('internal')
-    end
-  end
-
   shared_examples_for 'with ec2authtoken auth uri set' do
     before do
       params.merge!(
@@ -299,17 +269,6 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for "with custom keystone project_domain_* and user_domain_*" do
-    before do
-      params.merge!({
-        :keystone_user_domain_name => 'domain1',
-      })
-    end
-    it 'configures project_domain_* and user_domain_*' do
-      is_expected.to contain_heat_config('trustee/user_domain_name').with_value("domain1");
-    end
-  end
-
   shared_examples_for "with enable_stack_adopt and enable_stack_abandon set" do
     before do
       params.merge!({
@@ -323,20 +282,22 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for 'with overridden transport_url parameter' do
+  shared_examples_for 'with overridden messaging default parameters' do
     before do
       params.merge!(
-        :default_transport_url => 'rabbit://rabbit_user:password@localhost:5673',
-        :rpc_response_timeout  => '120',
-        :control_exchange      => 'heat',
+        :default_transport_url     => 'rabbit://rabbit_user:password@localhost:5673',
+        :rpc_response_timeout      => 120,
+        :control_exchange          => 'heat',
+        :executor_thread_pool_size => 64,
       )
     end
 
-    it 'configures transport_url' do
+    it 'configures messaging default parameters' do
       is_expected.to contain_oslo__messaging__default('heat_config').with(
-        :transport_url        => 'rabbit://rabbit_user:password@localhost:5673',
-        :rpc_response_timeout => '120',
-        :control_exchange     => 'heat'
+        :transport_url             => 'rabbit://rabbit_user:password@localhost:5673',
+        :rpc_response_timeout      => 120,
+        :control_exchange          => 'heat',
+        :executor_thread_pool_size => 64,
       )
     end
   end
@@ -420,7 +381,7 @@ describe 'heat' do
       end
 
       let :platform_params do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :common_package_name => 'heat-common' }
         when 'RedHat'
